@@ -1,4 +1,5 @@
-#!/usr/bin/python
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
 
 # This script removes branch and/or line coverage data for lines that
 # contain a particular substring.
@@ -38,7 +39,10 @@ for line in sys.stdin:
 
     # Source file
     if keyword == 'SF':
-        source = file(rest).readlines()
+
+        with open(rest, 'r') as pFile:
+
+            source = pFile.readlines()
 
     # Branch coverage data
     elif keyword == 'BRDA':
@@ -50,4 +54,4 @@ for line in sys.stdin:
         if check_suppress(line_suppress, source, rest):
             continue
 
-    print line
+    print(line)
